'''
risk_manage_engine/risk_calculator.py

리스크 관리 엔진의 통합 계산기 모듈입니다.

- 개별 리스크 지표 모듈들을 불러와 한 번에 계산
- 분석 엔진에서 전달된 종목 CDS에 대해 VaR, SVaR, MCS, ATR 계산 수행
- 결과는 하나의 딕셔너리로 반환
'''

import pandas as pd
from risk_manage_engine.calculators.var import calculate_var
from risk_manage_engine.calculators.svar import calculate_svar
from risk_manage_engine.calculators.monte_carlo import monte_carlo_var
from risk_manage_engine.calculators.atr import calculate_atr

def calculate_all_risks(df: pd.DataFrame, confidence_level: float = 0.95) -> dict:
    """
    CDS에 대해 모든 리스크 지표 계산

    Parameters:
        df (pd.DataFrame): 단일 종목의 CDS
        confidence_level (float): 신뢰 수준 (기본 95%)

    Returns:
        dict: {'var': ..., 'svar': ..., 'mcs': ..., 'atr': ...}
    """
    return {
        'var': calculate_var(df, confidence_level),
        'svar': calculate_svar(df, confidence_level),
        'mcs': monte_carlo_var(df, confidence_level=confidence_level),
        'atr': calculate_atr(df)
    }
